﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AccountController.cs" company="Eyal Shilony">
// 	© 2012 Eyal Shilony, All rights reserved.
// </copyright>
// --------------------------------------------------------------------------------------------------------------------

namespace EasyFront.Web.Desktop.Controllers
{
	using System.Diagnostics.Contracts;
	using System.Web.Mvc;
	using System.Web.Security;

	using EasyFront.Core.Web.Mvc;
	using EasyFront.Core.Web.Security.Authentication;
	using EasyFront.Web.Desktop.ViewModel;

	public class AccountController : Controller
	{
		private readonly IAuthenticationService authenticationService;

		public AccountController(IAuthenticationService authenticationService)
		{
			Contract.Requires(authenticationService != null);

			this.authenticationService = authenticationService;
		}

		public ActionResult SignIn()
		{
			return View();
		}

		[HttpPost]
		[CaptchaValidation]
		public ActionResult SignIn(LoginViewModel model, string returnUrl)
		{
			Contract.Requires(model != null);

			if (ModelState.IsValid)
			{
				Contract.Assume(!string.IsNullOrEmpty(model.Username));
				Contract.Assume(!string.IsNullOrEmpty(model.Password));

				bool isAuthenticated = authenticationService.SignIn(model.Username, model.Password);

				if (isAuthenticated)
				{
					FormsAuthentication.SetAuthCookie(model.Username, model.RememberMe);

					if (Url.IsLocalUrl(returnUrl) && returnUrl.Length > 1 && returnUrl.StartsWith("/") && !returnUrl.StartsWith("//") && !returnUrl.StartsWith("/\\"))
					{
						return Redirect(returnUrl);
					}

					return RedirectToAction("Index", "Home");
				}

				ModelState.AddModelError(string.Empty, "The username or password provided is incorrect.");
			}

			// If we got this far, something failed, redisplay form
			return View();
		}

		public ActionResult SignOut()
		{
			FormsAuthentication.SignOut();

			return RedirectToAction("Index", "Home");
		}
	}
}